@@ -2,7 +2,7 @@
 #-------------------------------------------------------------------------
 # Module: Gbook
 # Author: Jos (josvd@live.nl)
-# Version: 2.0.3
+# Version: 2.2.1
 #
 #-------------------------------------------------------------------------
 # CMS - CMS Made Simple is (c) 2009 by Ted Kulp (wishy@cmsmadesimple.org)
@@ -43,7 +43,7 @@ class Gbook extends CMSModule
 
 	function GetVersion()
 	{
-		return '2.0.3';
+		return '2.2.1';
 	}
 
 	function GetHelp()
@@ -124,10 +124,14 @@ class Gbook extends CMSModule
 		$this->SetParameterType('token',CLEAN_STRING);
 		$this->SetParameterType('name',CLEAN_STRING);
 		$this->SetParameterType('email',CLEAN_STRING);
+		$this->SetParameterType('website',CLEAN_STRING);
 		$this->SetParameterType('title',CLEAN_STRING);
 		$this->SetParameterType('message',CLEAN_STRING);
+		$this->SetParameterType('rating',CLEAN_INT);
 		$this->SetParameterType('notify',CLEAN_INT);
 		$this->SetParameterType('submit',CLEAN_STRING);
+		$this->SetParameterType('captcha_input',CLEAN_STRING);
+		$this->SetParameterType('validate',CLEAN_STRING);
 	}
 
 	function SetParameters()
