@@ -30,7 +30,7 @@ else
 
 if ( !empty($entry) )
 {
-	$smarty->assign_by_ref('gbook_entry', $entry);
+	$smarty->assign('gbook_entry', $entry);
 
 	// get template
 	$template = $this->GetPreference('default_detail_template');
