@@ -19,7 +19,9 @@ class Gbook_utils
 		$db = cmsms()->GetDB();
 		$query = "SELECT
 								g.*,
-								COUNT(e.entry_id) AS entries
+								COUNT(e.entry_id) AS entries,
+								COUNT(e.rating) AS ratings,
+								AVG(e.rating) AS rating_average
 							FROM
 								" . cms_db_prefix() . "module_gbook g
 							LEFT JOIN
@@ -134,6 +136,7 @@ class Gbook_utils
 					$onerow->message = self::filter_badwords($onerow->message);
 				}
 				$onerow->rawmessage = $row['message'];
+				$onerow->rating = $row['rating'];
 				$onerow->notify = $row['notify'];
 				$onerow->ip = $row['ip'];
 				$onerow->create_date = $row['create_date'];
@@ -170,7 +173,7 @@ class Gbook_utils
 		$result = $db->Execute($query, array($entry_id));
 		if ( $result && $result->RecordCount() > 0 )
 		{
-		  $row = $result->FetchRow();
+			$row = $result->FetchRow();
 			$onerow = new stdClass();
 			$onerow->entry_id = $row['entry_id'];
 			$onerow->gbook_id = $row['gbook_id'];
@@ -191,6 +194,7 @@ class Gbook_utils
 				$onerow->message = self::filter_badwords($onerow->message);
 			}
 			$onerow->rawmessage = $row['message'];
+			$onerow->rating = $row['rating'];
 			$onerow->notify = $row['notify'];
 			$onerow->ip = $row['ip'];
 			$onerow->create_date = $row['create_date'];
@@ -210,7 +214,7 @@ class Gbook_utils
 	}
 
 	
-	public static function AddEntry($gbook_id, $name, $email, $title, $message, $notify = 0) {
+	public static function AddEntry($gbook_id, $name, $email, $title, $message, $rating, $notify = 0) {
 		$mod = cms_utils::get_module('Gbook');
 		
 		// get gbook props
@@ -239,12 +243,14 @@ class Gbook_utils
 
 		// check for valid input
 		$required_fields = explode(',', $gbook['required_fields'] . ',message');
-		$name = strip_tags($name);
-		$email = strip_tags($email);
-		$title = strip_tags($title);
+		$name = trim(strip_tags($name));
+		$email = trim(strip_tags($email));
+		$title = trim(strip_tags($title));
+		$rating = trim(strip_tags($rating));
 		if ( in_array('name',  $required_fields) && empty($name) ) $errors[] = 'name';
 		if ( in_array('email', $required_fields) && !is_email($email, false) ) $errors[] = 'email';
 		if ( in_array('title', $required_fields) && empty($title) ) $errors[] = 'title';
+		if ( in_array('rating', $required_fields) && empty($rating) ) $errors[] = 'rating';
 		if ( empty($message) ) $errors[] = 'message';
 		
 		if ( !empty($errors) )
@@ -264,15 +270,16 @@ class Gbook_utils
 			{
 				$db = cmsms()->GetDB();
 				$query = "INSERT INTO " . cms_db_prefix() . "module_gbook_entries 
-										(gbook_id, name, email, title, message, notify, ip, create_date, modified_date, activation_code, active)
+										(gbook_id, name, email, title, message, rating, notify, ip, create_date, modified_date, activation_code, active)
 									VALUES
-										(?, ?, ?, ?, ?, ?, ?, NOW(), NOW(), ?, ?)";
+										(?, ?, ?, ?, ?, ?, ?, ?, NOW(), NOW(), ?, ?)";
 				$result = $db->Execute($query, array(
 						$gbook_id, 
 						$name, 
 						$email, 
 						$title, 
-						$message, 
+						$message,
+						$rating,
 						$notify,
 						$ip,
 						'',
@@ -289,6 +296,7 @@ class Gbook_utils
 						$params['email'] = $email;
 						$params['title'] = $title;
 						$params['message'] = $message;
+						$params['rating'] = $rating;
 						$params['notify'] = $notify;
 						$params['ip'] = $ip;
 						$params['active'] = $active;
@@ -321,9 +329,9 @@ class Gbook_utils
 	
 	public static function EditEntry($entry_id, $gbook_id, $name, $email, $title, $message, $notify, $active) {
 		// only admin, so no need to check for valid input, just strip tags
-		$name = strip_tags($name);
-		$email = strip_tags($email);
-		$title = strip_tags($title);
+		$name = trim(strip_tags($name));
+		$email = trim(strip_tags($email));
+		$title = trim(strip_tags($title));
 
 		$db = cmsms()->GetDB();
 		$query = "UPDATE " . cms_db_prefix() . "module_gbook_entries SET
@@ -384,6 +392,12 @@ class Gbook_utils
 	}
 
 	
+	public static function ActivateEntry($entry_id) {
+		$entry = self::GetEntry($entry_id);
+		self::EditEntry($entry_id, $entry->gbook_id, $entry->name, $entry->email, $entry->title, $entry->rawmessage, $entry->notify, 1);
+	}
+
+	
 	public static function DeleteEntry($entry_id) {
 		$db = cmsms()->GetDB();
 		$query = "DELETE FROM " . cms_db_prefix() . "module_gbook_entries WHERE entry_id = ?";
